/*
    Парус 8 - Панели мониторинга - РО - Редактор настройки регламентированного отчёта
    Компонент панели: Диалог дополнительной информации
*/

//---------------------
//Подключение библиотек
//---------------------

import React from "react"; //Классы React
import PropTypes from "prop-types"; //Контроль свойств компонента
import { Typography, List, ListItem } from "@mui/material"; //Интерфейсные элементы
import { Form } from "./form"; //Типовая форма

//---------
//Константы
//---------

//Стили
const STYLES = {
    HELP_LIST_ITEM: { padding: "0px 0px 0px 5px", whiteSpace: "pre" },
    HELP_LIST_ITEM_NAME: { fontWeight: "bold", minWidth: "45px" }
};

//------------------------------------
//Вспомогательные функции и компоненты
//------------------------------------

//Элемент списка расшифровки состава
const HelpListItem = ({ name, desc }) => {
    return (
        <ListItem sx={STYLES.HELP_LIST_ITEM}>
            <Typography sx={STYLES.HELP_LIST_ITEM_NAME}>{name}</Typography>
            <Typography>{` - ${desc}`}</Typography>
        </ListItem>
    );
};

//Контроль свойств - Элемент списка расшифровки состава
HelpListItem.propTypes = {
    name: PropTypes.string.isRequired,
    desc: PropTypes.string.isRequired
};

//-----------
//Тело модуля
//-----------

//Диалог дополнительной информации
const DialogHelp = ({ onClose }) => {
    //При закрытии диалога
    const handleClose = () => onClose && onClose();

    //Генерация содержимого
    return (
        <Form title={"Информация"} onClose={handleClose}>
            <Typography>Карточки показателей содержат сокращенную информацию о типе состава показателя. Список сокращений:</Typography>
            <List disablePadding={true}>
                <HelpListItem name={"fx"} desc={"формула"} />
                <HelpListItem name={"СЗ"} desc={"статическое значение"} />
                <HelpListItem name={"ХП"} desc={"хранимая процедура"} />
                <HelpListItem name={"РП"} desc={"расчетный показатель"} />
                <HelpListItem name={"ХО"} desc={"хозяйственные операции"} />
                <HelpListItem name={"РСДК"} desc={"расчёты с дебиторами/кредиторами"} />
                <HelpListItem name={"ОС"} desc={"остатки средств по счетам"} />
                <HelpListItem name={"ТМЦ"} desc={"остатки товарно-материальных ценностей"} />
                <HelpListItem name={"ДКЗ"} desc={"дебиторская/кредиторская задолженность"} />
                <HelpListItem name={"ИК"} desc={"инвентарная картотека"} />
                <HelpListItem name={"МБП"} desc={"картотека МБП"} />
                <HelpListItem name={"КОБП"} desc={"картотека операций будущих периодов"} />
                <HelpListItem name={"ДПНП"} desc={"декларация по налогу на прибыль"} />
                <HelpListItem name={"РО"} desc={"регламентированный отчет"} />
            </List>
        </Form>
    );
};

//Контроль свойств - Диалог дополнительной информации
DialogHelp.propTypes = {
    onClose: PropTypes.func
};

//----------------
//Интерфейс модуля
//----------------

export { DialogHelp };
