/*
    Парус 8 - Панели мониторинга - РО - Редактор настройки регламентированного отчёта
    Компонент панели: Поле ввода формы
*/

//---------------------
//Подключение библиотек
//---------------------

import React, { useState, useEffect } from "react"; //Классы React
import PropTypes from "prop-types"; //Контроль свойств компонента
import { Box, Icon, Input, InputAdornment, FormControl, Select, InputLabel, MenuItem, IconButton, Autocomplete, TextField } from "@mui/material"; //Интерфейсные компоненты

//---------
//Константы
//---------

//Формат свойств поля формы
const FORM_FILED = {
    elementCode: PropTypes.string.isRequired,
    elementValue: PropTypes.oneOfType([PropTypes.number, PropTypes.string, PropTypes.instanceOf(Date)]),
    labelText: PropTypes.string.isRequired,
    onChange: PropTypes.func,
    dictionary: PropTypes.func,
    list: PropTypes.array,
    type: PropTypes.string,
    freeSolo: PropTypes.bool,
    disabled: PropTypes.bool,
    formValues: PropTypes.object
};

//-----------
//Тело модуля
//-----------

//Поле ввода формы
const FormField = ({
    elementCode,
    elementValue,
    labelText,
    onChange,
    dictionary,
    list,
    type,
    freeSolo = false,
    disabled = false,
    formValues,
    ...other
}) => {
    //Значение элемента
    const [value, setValue] = useState(elementValue);

    //При получении нового значения из вне
    useEffect(() => {
        setValue(elementValue);
    }, [elementValue]);

    //Выбор значения из словаря
    const handleDictionaryClick = () => dictionary && dictionary(formValues, res => (res ? res.map(i => handleChangeByName(i.name, i.value)) : null));

    //Изменение значения элемента (по событию)
    const handleChange = e => {
        setValue(e.target.value);
        if (onChange) onChange(e.target.name, e.target.value);
    };

    //Изменение значения элемента (по имени и значению)
    const handleChangeByName = (name, value) => {
        if (name === elementCode) setValue(value);
        if (onChange) onChange(name, value);
    };

    //Генерация содержимого
    return (
        <Box p={1}>
            <FormControl variant="standard" fullWidth {...other}>
                {list ? (
                    freeSolo ? (
                        <Autocomplete
                            id={elementCode}
                            name={elementCode}
                            freeSolo
                            disabled={disabled}
                            inputValue={value ? value : ""}
                            onChange={(event, newValue) => handleChangeByName(elementCode, newValue)}
                            onInputChange={(event, newInputValue) => handleChangeByName(elementCode, newInputValue)}
                            options={list}
                            renderInput={params => <TextField {...params} label={labelText} name={elementCode} variant={"standard"} />}
                        />
                    ) : (
                        <>
                            <InputLabel id={`${elementCode}Lable`} shrink>
                                {labelText}
                            </InputLabel>
                            <Select
                                labelId={`${elementCode}Lable`}
                                id={elementCode}
                                name={elementCode}
                                label={labelText}
                                value={[undefined, null].includes(value) ? "" : value}
                                onChange={handleChange}
                                disabled={disabled}
                                displayEmpty
                            >
                                {list.map((item, i) => (
                                    <MenuItem key={i} value={[undefined, null].includes(item.value) ? "" : item.value}>
                                        {item.name}
                                    </MenuItem>
                                ))}
                            </Select>
                        </>
                    )
                ) : (
                    <>
                        <InputLabel {...(type == "date" ? { shrink: true } : {})} htmlFor={elementCode}>
                            {labelText}
                        </InputLabel>
                        <Input
                            id={elementCode}
                            name={elementCode}
                            value={value ? value : ""}
                            endAdornment={
                                dictionary ? (
                                    <InputAdornment position="end">
                                        <IconButton aria-label={`${elementCode} select`} onClick={handleDictionaryClick} edge="end">
                                            <Icon>list</Icon>
                                        </IconButton>
                                    </InputAdornment>
                                ) : null
                            }
                            {...(type ? { type } : {})}
                            onChange={handleChange}
                            disabled={disabled}
                        />
                    </>
                )}
            </FormControl>
        </Box>
    );
};

//Контроль свойств - Поле ввода формы
FormField.propTypes = FORM_FILED;

//----------------
//Интерфейс модуля
//----------------

export { FORM_FILED, FormField };
